summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rw-r--r--scripts/Makefile.lib6
-rwxr-xr-xscripts/check_known_checkpatch_issues.sh6
-rwxr-xr-xscripts/do_checkpatch.sh2
-rwxr-xr-xscripts/link-tinymountain.sh14
-rwxr-xr-xscripts/maintainer-checkpatch.bash4
-rwxr-xr-xscripts/sanity_chk/common-klibs_chk12
-rw-r--r--scripts/sanity_chk/common.defs8
-rwxr-xr-xscripts/sanity_chk/footprint_chk12
-rwxr-xr-xscripts/sanity_chk/out-of-tree_chk20
-rwxr-xr-xscripts/sanity_chk/regression_chk10
-rwxr-xr-xscripts/sanity_chk/sanity_chk12
-rwxr-xr-xscripts/sysgen.py4
12 files changed, 55 insertions, 55 deletions
diff --git a/scripts/Makefile.lib b/scripts/Makefile.lib
index 01da612b2..ef5ea4d7b 100644
--- a/scripts/Makefile.lib
+++ b/scripts/Makefile.lib
@@ -139,14 +139,14 @@ __a_flags = $(call flags,_a_flags)
__cpp_flags = $(call flags,_cpp_flags)
endif
-c_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(TIMOINCLUDE) \
+c_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(ZEPHYRINCLUDE) \
$(__c_flags) $(modkern_cflags) \
-D"KBUILD_STR(s)=\#s" $(basename_flags) $(modname_flags)
-a_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(TIMOINCLUDE) \
+a_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(ZEPHYRINCLUDE) \
$(__a_flags) $(modkern_aflags)
-cpp_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(TIMOINCLUDE) \
+cpp_flags = -Wp,-MD,$(depfile) $(NOSTDINC_FLAGS) $(ZEPHYRINCLUDE) \
$(__cpp_flags)
ld_flags = $(LDFLAGS) $(ldflags-y)
diff --git a/scripts/check_known_checkpatch_issues.sh b/scripts/check_known_checkpatch_issues.sh
index 651bab276..02a3a6be0 100755
--- a/scripts/check_known_checkpatch_issues.sh
+++ b/scripts/check_known_checkpatch_issues.sh
@@ -39,8 +39,8 @@
exe_name=$(basename $0)
-do_checkpatch_bin=${TIMO_BASE}/scripts/do_checkpatch.sh
-timestamp_bin=${TIMO_BASE}/scripts/timestamp
+do_checkpatch_bin=${ZEPHYR_BASE}/scripts/do_checkpatch.sh
+timestamp_bin=${ZEPHYR_BASE}/scripts/timestamp
declare update=n
declare quiet=n
@@ -89,7 +89,7 @@ uid=$(id -u)
pid=$$
suffix=${uid}-${pid}-${ts}
checkpatch_results=/tmp/checkpatch.results-${suffix}
-known_checkpatch_issues=${TIMO_BASE}/scripts/known_checkpatch_issues
+known_checkpatch_issues=${ZEPHYR_BASE}/scripts/known_checkpatch_issues
checkpatch_issues=/tmp/checkpatch_issues-${suffix}
git_log_params="\
--abbrev=8 \
diff --git a/scripts/do_checkpatch.sh b/scripts/do_checkpatch.sh
index ea448a484..06595210d 100755
--- a/scripts/do_checkpatch.sh
+++ b/scripts/do_checkpatch.sh
@@ -37,7 +37,7 @@
dirs_to_check="arch drivers include kernel lib"
files=$(for d in ${dirs_to_check}; do find $d/ -type f -name '*.[ch]'; done)
for i in $files; do
- ${TIMO_BASE}/scripts/checkpatch.pl --mailback --no-tree -f --emacs --summary-file --show-types --ignore BRACES,PRINTK_WITHOUT_KERN_LEVEL,SPLIT_STRING --max-line-length=100 $i >> $1
+ ${ZEPHYR_BASE}/scripts/checkpatch.pl --mailback --no-tree -f --emacs --summary-file --show-types --ignore BRACES,PRINTK_WITHOUT_KERN_LEVEL,SPLIT_STRING --max-line-length=100 $i >> $1
done
grep ERROR: $1 |cut -d : -f 3,4 |sort -u > $1_error.types
grep WARNING: $1 |cut -d : -f 3,4 |sort -u > $1_warning.types
diff --git a/scripts/maintainer-checkpatch.bash b/scripts/maintainer-checkpatch.bash
index 4229cf6af..ad89778c6 100755
--- a/scripts/maintainer-checkpatch.bash
+++ b/scripts/maintainer-checkpatch.bash
@@ -48,9 +48,9 @@ checkpatch_switches="\
"
ignore_list=BRACES,PRINTK_WITHOUT_KERN_LEVEL,SPLIT_STRING,FILE_PATH_CHANGES
-timestamp_bin=${TIMO_BASE}/scripts/timestamp
+timestamp_bin=${ZEPHYR_BASE}/scripts/timestamp
timestamp="${timestamp_bin} -u"
-checkpatch_bin=${TIMO_BASE}/scripts/checkpatch.pl
+checkpatch_bin=${ZEPHYR_BASE}/scripts/checkpatch.pl
checkpatch="${checkpatch_bin} ${checkpatch_switches} --ignore ${ignore_list}"
ts=$(${timestamp})
diff --git a/scripts/sanity_chk/common-klibs_chk b/scripts/sanity_chk/common-klibs_chk
index a8235c98f..375a3c1e3 100755
--- a/scripts/sanity_chk/common-klibs_chk
+++ b/scripts/sanity_chk/common-klibs_chk
@@ -33,20 +33,20 @@
# Import common sanity check definitions
#
-if [ -z ${TIMO_BASE} ]; then
+if [ -z ${ZEPHYR_BASE} ]; then
echo "shell variables required to build Zephyr OS are not set"
exit 1
fi
-if [ ! -d ${TIMO_BASE} ] ; then
- echo "directory ${TIMO_BASE} not found"
+if [ ! -d ${ZEPHYR_BASE} ] ; then
+ echo "directory ${ZEPHYR_BASE} not found"
exit 1
fi
-source ${TIMO_BASE}/scripts/sanity_chk/common.defs
+source ${ZEPHYR_BASE}/scripts/sanity_chk/common.defs
# Location of master project directory
#
-PRJ_PATH=${TIMO_BASE}/samples
-KLIBS_PRJ_PATH=${TIMO_BASE}/samples
+PRJ_PATH=${ZEPHYR_BASE}/samples
+KLIBS_PRJ_PATH=${ZEPHYR_BASE}/samples
TEST_PRJ_PATH=./
# Pseudo-file describing sample projects to be sanitized
diff --git a/scripts/sanity_chk/common.defs b/scripts/sanity_chk/common.defs
index 1aa4362eb..cef7bb3e9 100644
--- a/scripts/sanity_chk/common.defs
+++ b/scripts/sanity_chk/common.defs
@@ -60,12 +60,12 @@ KEEP_LOGS=0
SANITY_CHK_LOG="sanity_chk.log"
# directory containing code coverage results
-CC_DIR=${TIMO_BASE}/codecoverage/`${BASENAME} $0`/
-HTML_CC_DIR=${TIMO_BASE}/codecoverage_html/`${BASENAME} $0`/
+CC_DIR=${ZEPHYR_BASE}/codecoverage/`${BASENAME} $0`/
+HTML_CC_DIR=${ZEPHYR_BASE}/codecoverage_html/`${BASENAME} $0`/
# temporary files used when selecting projects to be sanitized
-TEMP_AWK_PROG="${TIMO_BASE}/.tempawkprog"
-TEMP_PRJ_LIST="${TIMO_BASE}/.tempprojlist"
+TEMP_AWK_PROG="${ZEPHYR_BASE}/.tempawkprog"
+TEMP_PRJ_LIST="${ZEPHYR_BASE}/.tempprojlist"
# maximum time (in seconds) to allow QEMU to execute a project
QEMU_TIME_LIMIT=300
diff --git a/scripts/sanity_chk/footprint_chk b/scripts/sanity_chk/footprint_chk
index 7ef13c236..c1a9e71bd 100755
--- a/scripts/sanity_chk/footprint_chk
+++ b/scripts/sanity_chk/footprint_chk
@@ -33,22 +33,22 @@
# Import common sanity check definitions
#
-if [ -z ${TIMO_BASE} ]; then
+if [ -z ${ZEPHYR_BASE} ]; then
echo "shell variables required to build Zephyr OS are not set"
exit 1
fi
-if [ ! -d ${TIMO_BASE} ] ; then
- echo "directory ${TIMO_BASE} not found"
+if [ ! -d ${ZEPHYR_BASE} ] ; then
+ echo "directory ${ZEPHYR_BASE} not found"
exit 1
fi
-source ${TIMO_BASE}/scripts/sanity_chk/common.defs
+source ${ZEPHYR_BASE}/scripts/sanity_chk/common.defs
# Additional commands used in script
-SIZE="${TIMO_BASE}/scripts/truesize"
+SIZE="${ZEPHYR_BASE}/scripts/truesize"
# Location of master project directory
#
-PRJ_PATH=${TIMO_BASE}/samples
+PRJ_PATH=${ZEPHYR_BASE}/samples
# Pseudo-file describing sample projects to be characterized
#
diff --git a/scripts/sanity_chk/out-of-tree_chk b/scripts/sanity_chk/out-of-tree_chk
index addcec461..df6f17516 100755
--- a/scripts/sanity_chk/out-of-tree_chk
+++ b/scripts/sanity_chk/out-of-tree_chk
@@ -36,18 +36,18 @@ exit 0
# Import common sanity check definitions
#
-if [ -z ${TIMO_BASE} ]; then
+if [ -z ${ZEPHYR_BASE} ]; then
echo "shell variables required to build Zephyr OS are not set"
exit 1
fi
-if [ ! -d ${TIMO_BASE} ] ; then
- echo "directory ${TIMO_BASE} not found"
+if [ ! -d ${ZEPHYR_BASE} ] ; then
+ echo "directory ${ZEPHYR_BASE} not found"
exit 1
fi
-source ${TIMO_BASE}/scripts/sanity_chk/common.defs
+source ${ZEPHYR_BASE}/scripts/sanity_chk/common.defs
# Out of tree location
-OUT_OF_TREE_BASE_REL=${TIMO_BASE}/../$(basename ${TIMO_BASE})-sanity
+OUT_OF_TREE_BASE_REL=${ZEPHYR_BASE}/../$(basename ${ZEPHYR_BASE})-sanity
OUT_OF_TREE_BASE=$(${ABS_PATH} ${OUT_OF_TREE_BASE_REL})
# Location of master project directory
@@ -132,8 +132,8 @@ possible; if desired the script can be instructed to skip the QEMU execution
step.
BSPs and samples are copied to:
- TIMO_BASE/../sanity/bsp
- TIMO_BASE/../sanity/samples
+ ZEPHYR_BASE/../sanity/bsp
+ ZEPHYR_BASE/../sanity/samples
The script returns 0 on success. If an error is encountered at any point
the script returns the exit value of the command that failed, the function
@@ -246,13 +246,13 @@ main() {
${MKDIR} -p ${OUT_OF_TREE_BASE}
# copy the BSPs
- ${CP} -r ${TIMO_BASE}/target/bsp ${OUT_OF_TREE_BASE}
+ ${CP} -r ${ZEPHYR_BASE}/target/bsp ${OUT_OF_TREE_BASE}
[ $? -eq 0 ] || fail_exit $? $FUNCNAME $LINENO
# copy the samples/include directory used by certain projects
${MKDIR} -p ${PRJ_PATH}
[ $? -eq 0 ] || fail_exit $? $FUNCNAME $LINENO
- ${CP} -r ${TIMO_BASE}/samples/include ${PRJ_PATH}
+ ${CP} -r ${ZEPHYR_BASE}/samples/include ${PRJ_PATH}
[ $? -eq 0 ] || fail_exit $? $FUNCNAME $LINENO
# build (and optionally execute) projects
@@ -271,7 +271,7 @@ main() {
${MKDIR} -p ${PRJ_PATH}/${PRJ_NAME[${cur_proj}]}
[ $? -eq 0 ] || fail_exit $? $FUNCNAME $LINENO
- ${CP} -r ${TIMO_BASE}/samples/${PRJ_NAME[${cur_proj}]}/* ${PRJ_PATH}/${PRJ_NAME[${cur_proj}]}
+ ${CP} -r ${ZEPHYR_BASE}/samples/${PRJ_NAME[${cur_proj}]}/* ${PRJ_PATH}/${PRJ_NAME[${cur_proj}]}
[ $? -eq 0 ] || fail_exit $? $FUNCNAME $LINENO
# build project
diff --git a/scripts/sanity_chk/regression_chk b/scripts/sanity_chk/regression_chk
index 357ef7434..4bb64c229 100755
--- a/scripts/sanity_chk/regression_chk
+++ b/scripts/sanity_chk/regression_chk
@@ -33,19 +33,19 @@
# Import common sanity check definitions
#
-if [ -z ${TIMO_BASE} ]; then
+if [ -z ${ZEPHYR_BASE} ]; then
echo "shell variables required to build Zephyr OS are not set"
exit 1
fi
-if [ ! -d ${TIMO_BASE} ] ; then
- echo "directory ${TIMO_BASE} not found"
+if [ ! -d ${ZEPHYR_BASE} ] ; then
+ echo "directory ${ZEPHYR_BASE} not found"
exit 1
fi
-source ${TIMO_BASE}/scripts/sanity_chk/common.defs
+source ${ZEPHYR_BASE}/scripts/sanity_chk/common.defs
# Location of master project directory
#
-PRJ_PATH=${TIMO_BASE}/samples
+PRJ_PATH=${ZEPHYR_BASE}/samples
# Pseudo-file describing sample projects to be sanitized
#
diff --git a/scripts/sanity_chk/sanity_chk b/scripts/sanity_chk/sanity_chk
index 033a05e7d..7b1c61b21 100755
--- a/scripts/sanity_chk/sanity_chk
+++ b/scripts/sanity_chk/sanity_chk
@@ -33,20 +33,20 @@
# Import common sanity check definitions
#
-if [ -z ${TIMO_BASE} ]; then
+if [ -z ${ZEPHYR_BASE} ]; then
echo "shell variables required to build Zephyr OS are not set"
exit 1
fi
-if [ ! -d ${TIMO_BASE} ] ; then
- echo "directory ${TIMO_BASE} not found"
+if [ ! -d ${ZEPHYR_BASE} ] ; then
+ echo "directory ${ZEPHYR_BASE} not found"
exit 1
fi
-source ${TIMO_BASE}/scripts/sanity_chk/common.defs
+source ${ZEPHYR_BASE}/scripts/sanity_chk/common.defs
# Symbols used in this script only
#
-SCRIPT_PATH=${TIMO_BASE}/scripts/sanity_chk
-HOST_TOOLS_SRC_PATH=${TIMO_BASE}/host/src
+SCRIPT_PATH=${ZEPHYR_BASE}/scripts/sanity_chk
+HOST_TOOLS_SRC_PATH=${ZEPHYR_BASE}/host/src
# print script usage
#
diff --git a/scripts/sysgen.py b/scripts/sysgen.py
index 2a2affbae..99ba7a3da 100755
--- a/scripts/sysgen.py
+++ b/scripts/sysgen.py
@@ -1052,7 +1052,7 @@ def kernel_main_h_generate():
subprocess.check_call([
"cp",
"-f",
- os.environ["TIMO_BASE"] +
+ os.environ["ZEPHYR_BASE"] +
"/kernel/microkernel/include/kernel_main.h",
output_dir])
@@ -1070,7 +1070,7 @@ def kernel_struct_h_generate():
subprocess.check_call([
"cp",
"-f",
- os.environ["TIMO_BASE"] +
+ os.environ["ZEPHYR_BASE"] +
"/kernel/microkernel/include/kernel_struct.h",
output_dir])
diff --git a/scripts/link-tinymountain.sh b/scripts/link-tinymountain.sh
index 79b4d62c8..d4b9736a9 100755
--- a/scripts/link-tinymountain.sh
+++ b/scripts/link-tinymountain.sh
@@ -2,18 +2,18 @@
#
# link tinymountain
#
# tinymountain is linked from the objects selected by $(KBUILD_TIMO_INIT) and
# $(KBUILD_TIMO_MAIN). Most are built-in.o files from top-level directories
# in the kernel tree, others are specified in arch/$(ARCH)/Makefile.
# Ordering when linking is important, and $(KBUILD_TIMO_INIT) must be first.
#
# tinymountain
# ^
# |
-# +-< $(KBUILD_TIMO_INIT)
+# +-< $(KBUILD_ZEPHYR_INIT)
# | +--< init/version.o + more
# |
-# +--< $(KBUILD_TIMO_MAIN)
+# +--< $(KBUILD_ZEPHYR_MAIN)
# | +--< drivers/built-in.o mm/built-in.o + more
# |
# +-< ${kallsymso} (see description in KALLSYMS section)
@@ -49,7 +49,7 @@ linker_params()
echo "-L ${objtree}/include/generated" >> ${1}
echo "-u _OffsetAbsSyms -u _ConfigAbsSyms" >> ${1}
echo "-e __start" >> ${1}
- echo "--start-group ${KBUILD_TIMO_MAIN}" >> ${1}
+ echo "--start-group ${KBUILD_ZEPHYR_MAIN}" >> ${1}
echo "${objtree}/include/generated/offsets.o" >> ${1}
echo "--end-group" >> ${1}
echo "${LIB_INCLUDE_DIR} ${LIBS}" >> ${1}
@@ -133,7 +133,7 @@ kallsyms()
fi
local aflags="${KBUILD_AFLAGS} ${KBUILD_AFLAGS_KERNEL} \
- ${NOSTDINC_FLAGS} ${TIMOINCLUDE} ${KBUILD_CPPFLAGS}"
+ ${NOSTDINC_FLAGS} ${ZEPHYRINCLUDE} ${KBUILD_CPPFLAGS}"
${NM} -n ${1} | \
scripts/kallsyms ${kallsymopt} | \
@@ -2,18 +2,18 @@
# link tinymountain
#
-# tinymountain is linked from the objects selected by $(KBUILD_TIMO_INIT) and
-# $(KBUILD_TIMO_MAIN). Most are built-in.o files from top-level directories
+# zephyr is linked from the objects selected by $(KBUILD_ZEPHYR_INIT) and
+# $(KBUILD_ZEPHYR_MAIN). Most are built-in.o files from top-level directories
# in the kernel tree, others are specified in arch/$(ARCH)/Makefile.
@@ -2,18 +2,18 @@
# in the kernel tree, others are specified in arch/$(ARCH)/Makefile.
-# Ordering when linking is important, and $(KBUILD_TIMO_INIT) must be first.
+# Ordering when linking is important, and $(KBUILD_ZEPHYR_INIT) must be first.
#
# tinymountain